<?php

class PHPDS_core extends PHPDS_dependant {

	/**
	 * This creates a simple confirmation box to ask users input before performing a critical link click.
	 *
	 * @param string What is the question to be asked in the confirmation box.
	 * @return string Javascript popup confirmation box.
	 * @author Jason Schoeman
	 */
	public function confirmLink ($confirm_what)
	{
		$onclick = "onClick=\"return confirm('$confirm_what')\"";
		return eval('return $onclick;');
	}

	/**
	 * This creates a simple confirmation box to ask users input before performing a critical submit.
	 *
	 * @param string What is the question to be asked in the confirmation box.
	 * @return string Javascript popup confirmation box.
	 * @author Jason Schoeman
	 */
	public function confirmSubmit ($confirm_what)
	{
		$onclick = "onSubmit=\"return confirm('$confirm_what')\"";
		return eval('return $onclick;');
	}

	/**
	 * This shows a simple "alert" box which notifies the user about a specified condition.
	 *
	 * @param string The actual warning message.
	 * @return string Javascript popup warning box.
	 * @author Don Schoeman
	 */
	public function alertSubmit ($alert_msg)
	{
		$onclick = "onSubmit=\"alert('$alert_msg')\"";
		return eval('return $onclick;');
	}

	/**
	 * This shows a simple "alert" box which notifies the user about a specified condition.
	 *
	 * @param string The actual warning message.
	 * @return string Javascript popup warning box.
	 * @author Don Schoeman
	 */
	public function alertLink ($alert_msg)
	{
		$onclick = "onClick=\"alert('$alert_msg')\"";
		return eval('return $onclick;');
	}

	/**
	 * Check and returns constant if constant is defined or returns normal variable if no constant defined.
	 *
	 * @param string The string to check whether variable or constant.
	 * @return string The actual assigned constant value.
	 * @author Jason Schoeman
	 */
	public function isConstant ($is_variable_constant)
	{
		if (defined($is_variable_constant)) {
			return constant($is_variable_constant);
		} else {
			return $is_variable_constant;
		}
	}

	/**
	 * This method will return the correct user time taking DST and users timezone into consideration.
	 *
	 * @param integer $timestamp Unix timestamp if empty it will return the current users time.
	 * @param string $format_type_or_custom User can choose which of the formats to load from the $this->configuration settings, 'default', 'short' or have a custom format.
	 * @param string $custom_timezone You can also provide a custom timezone to this method, if false, it will use current users timezone.
	 * @return string Will return a formatted date string ex. 1 June 2011 18:05 PM
	 * @author Jason Schoeman
	 *
	 * @version 1.0.1	Converted to OOP
	 * @date	2009/05/19
	 */
	public function formatTimeDate ($time_stamp, $format_type_or_custom = 'default', $custom_timezone = false)
	{
		$configuration = $this->configuration;
		// Check if we habe an empty time stamp.
		if (empty($time_stamp)) return false;
		// Check if we have a custom timezone.
		if (! empty($custom_timezone)) {
			$timezone = $custom_timezone;
		} else if (! empty($configuration['user_timezone'])) {
			$timezone = $configuration['user_timezone'];
		} else {
			$timezone = $configuration['system_timezone'];
		}

		if ($format_type_or_custom == 'default') {
			$format = $configuration['date_format'];
		} else if ($format_type_or_custom == 'short') {
			$format = $configuration['date_format_short'];
		} else {
			$format = $format_type_or_custom;
		}
		if (phpversion() < '5.2.0') return strftime('%c', $time_stamp);
		try {
			$ut = new DateTime(date('Y-m-d H:i:s', $time_stamp));
			$tz = new DateTimeZone($timezone);
			$ut->setTimezone($tz);
		} catch (Exception $e) {
			// Work around error from old database column.
			$configuration['user_timezone'] = $configuration['system_timezone'];
			$this->template->debugStr = ___('There is a timezone problem, please set your timezone!');
			return date(DATE_RFC822);
		}

		return $ut->format($format);
	}

	/* Returns the difference in seconds between the currently logged in user's timezone
	 * and the server's configured timezone (under General Settings). If the server
	 * timezone is 2 hours behind the user timezone, it will return -7200 for example. If
	 * the server timezone is 2 hours ahead of the user timezone, it will return 7200.
	 *
	 * @param integer $custom_timestamp Timestamp to compare dates timezones in the future or past.
	 * @return integer The difference between the user's timezone and server timezone (in seconds).
	 * @author Don Schoeman
	 */
	public function userServerTzDiff ($custom_timestamp = false)
	{
		$configuration = $this->configuration;
		if (empty($custom_timestamp)) {
			$timestamp = $configuration['time'];
		} else {
			$timestamp = $custom_timestamp;
		}
		if (phpversion() < '5.2.0')
			return 0;
		$ut = new DateTime(date('Y-m-d H:i:s', $timestamp));
		$tz = new DateTimeZone($configuration['user_timezone']);
		$ut->setTimezone($tz);
		$user_timezone_sec = $ut->format('Z');
		$tz = new DateTimeZone($configuration['system_timezone']);
		$ut->setTimezone($tz);
		$server_timezone_sec = $ut->format('Z');
		return $server_timezone_sec - $user_timezone_sec;
	}

	/**
	 * This method creates a random string with mixed alphabetic characters.
	 *
	 * @param integer $length The lenght the string should be.
	 * @param boolean $uppercase_only Should the string be uppercase.
	 * @return string Will return required random string.
	 * @author Andy Shellam, andy [at] andycc [dot] net
	 */
	public function createRandomString ($length = 4, $uppercase_only = false)
	{
		if ($uppercase_only == true) {
			$template = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
		} else {
			$template = '1234567890abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
		}
		$length = $length - 1;
		$rndstring = false;
		$a = 0;
		$b = 0;
		settype($length, 'integer');
		settype($rndstring, 'string');
		settype($a, 'integer');
		settype($b, 'integer');
		for ($a = 0; $a <= $length; $a ++) {
			$b = rand(0, strlen($template) - 1);
			$rndstring .= $template[$b];
		}
		return $rndstring;
	}

	/**
	 * Function formats locale according to logged in user settings else will default to system.
	 *
	 * @param boolean $charset Whether the charset should be included in the format.
	 * @return string Will return formatted locale.
	 * @author Jason Schoeman
	 */
	public function formatLocale ($charset = true, $user_language = false, $user_region = false)
	{
		$configuration = $this->configuration;
		if (empty($configuration['charset_format'])) $configuration['charset_format'] = false;
		if (! empty($user_language)) $configuration['user_language'] = $user_language;
		if (! empty($user_region)) $configuration['user_region'] = $user_region;
		if (empty($configuration['user_language'])) $configuration['user_language'] = $configuration['language'];
		if (empty($configuration['user_region'])) $configuration['user_region'] = $configuration['region'];
		if ($charset && ! empty($configuration['charset_format'])) {
			$locale_format = preg_replace('/\{charset\}/', $configuration['charset_format'], $configuration['locale_format']);
			$locale_format = preg_replace('/\{lang\}/', $configuration['user_language'], $locale_format);
			$locale_format = preg_replace('/\{region\}/', $configuration['user_region'], $locale_format);
			$locale_format = preg_replace('/\{charset\}/', $configuration['charset'], $locale_format);
			return $locale_format;
		} else {
			$locale_format = preg_replace('/\{lang\}/', $configuration['user_language'], $configuration['locale_format']);
			$locale_format = preg_replace('/\{region\}/', $configuration['user_region'], $locale_format);
			$locale_format = preg_replace('/\{charset\}/', '', $locale_format);
			return $locale_format;
		}
	}

	/**
	 * This methods allows you to load translation by giving their locations and name.
	 *
	 * @param string This is the location where language mo file is found.
	 * @param string The mo filename the translation is compiled in.
	 * @param string The actual text domain identifier.
	 * @author Jason Schoeman
	 */
	public function loadTranslation ($mo_directory, $mo_filename, $textdomain)
	{
		$configuration = $this->configuration;
		$bindtextdomain = $configuration['absolute_path'] . $mo_directory;
		$loc_dir = $bindtextdomain . $configuration['locale_dir'] . '/LC_MESSAGES/' . $mo_filename;

		(file_exists($loc_dir)) ? $mo_ok = true : $mo_ok = false;
		if ($mo_ok) {
			$this->_log('Found Translation File : ' . $loc_dir);
			bindtextdomain($textdomain, $bindtextdomain);
			bind_textdomain_codeset($textdomain, $configuration['charset']);
			textdomain($textdomain);
		} else {
			$this->debugInstance()->warning('MISSING Translation File : ' . $loc_dir);
		}
	}

	/**
	 * This method loads the core language array and assigns it to a variable.
	 *
	 * @author Jason Schoeman
	 */
	public function loadCoreLanguage ()
	{
		$this->loadTranslation('language/', 'core.lang.mo', 'core.lang');
	}

	/**
	 * This method loads the default menu language array and assigns it to a variable.
	 *
	 * @author Jason Schoeman
	 */
	public function loadMenuLanguage ()
	{
		// Lets loop the installed plugins.
		foreach ($this->db->pluginsInstalled as $installed_plugins_array) {
			$plugin_folder = $installed_plugins_array['plugin_folder'];
			$this->loadTranslation("plugins/$plugin_folder/language/", "$plugin_folder.mo", "$plugin_folder");
		}
	}

	/**
	 * This method loads the plugin language with default items and icons array.
	 *
	 * @author Jason Schoeman
	 */
	public function loadDefaultPluginLanguage ()
	{
		$active_plugin = $this->activePlugin();
		textdomain($active_plugin);
	}

	/**
	 * Function to return the current running/active plugin.
	 *
	 * @return string
	 */
	public function activePlugin ()
	{
		$navigation = $this->navigation;
		$configuration = $this->configuration;

		if (! empty($configuration['m']) && ! empty($navigation->navigation[$configuration['m']]['plugin'])) {
			return $navigation->navigation[$this->configuration['m']]['plugin'];
		} else {
			return 'PHPDevShell';
		}
	}

	/**
	 * Function to return the current running/active template.
	 *
	 * @return string
	 */
	public function activeTemplate ()
	{
		$navigation = $this->navigation;
		if (! empty($navigation->navigation[$this->configuration['m']]['template_folder'])) {
			return $navigation->navigation[$this->configuration['m']]['template_folder'];
		} else {
			return false;
		}
	}

	/**
	 * Convert string unsigned CRC32 value. This is unique and can help predict a entries id beforehand.
	 * Use for folder names insuring unique id's.
	 *
	 * @param string To convert to integer.
	 * @return integer
	 * @author Jason Schoeman
	 */
	public function nameToId ($convert_to_id)
	{
		return sprintf('%u', crc32($convert_to_id));
	}

	/**
	 * Strip a string from the end of a string.
	 * Is there no such function in PHP?
	 *
	 * @param string $str      The input string.
	 * @param string $remove   OPTIONAL string to remove.
	 *
	 * @return string the modified string.
	 */
	public function rightTrim ($str, $remove = null)
	{
		$str = (string) $str;
		$remove = (string) $remove;
		if (empty($remove)) {
			return rtrim($str);
		}
		$len = strlen($remove);
		$offset = strlen($str) - $len;
		while ($offset > 0 && $offset == strpos($str, $remove, $offset)) {
			$str = substr($str, 0, $offset);
			$offset = strlen($str) - $len;
		}
		return rtrim($str);
	}

	/**
	 * This method simply renames a string to safe unix standards.
	 *
	 * @param string $name
	 * @param string $replace Replace odd characters with what?
	 *
	 * @return string
	 */
	public function safeName ($name, $replace = '-')
	{
		$search = array('--', '&quot;', '!', '@', '#', '$', '%', '^', '&', '*', '(', ')', '+', '{', '}', '|', ':', '"', '<', '>', '?', '[', ']', '\\', ';', "'", ',', '.', '/', '*', '+', '~', '`', '=', ' ');
		$new_replaced_name = strtolower(str_replace($search, $replace, $name));
		if (! empty($new_replaced_name)) {
			return $new_replaced_name;
		} else {
			return false;
		}
	}

	/**
	 * Replaces accents with plain text for a given string.
	 *
	 * @param string $string
	 */
	public function replaceAccents($string)
	{
		return str_replace( array('à','á','â','ã','ä', 'ç', 'è','é','ê','ë', 'ì','í','î','ï', 'ñ', 'ò','ó','ô','õ','ö', 'ù','ú','û','ü', 'ý','ÿ', 'À','Á','Â','Ã','Ä', 'Ç', 'È','É','Ê','Ë', 'Ì','Í','Î','Ï', 'Ñ', 'Ò','Ó','Ô','Õ','Ö', 'Ù','Ú','Û','Ü', 'Ý'), array('a','a','a','a','a', 'c', 'e','e','e','e', 'i','i','i','i', 'n', 'o','o','o','o','o', 'u','u','u','u', 'y','y', 'A','A','A','A','A', 'C', 'E','E','E','E', 'I','I','I','I', 'N', 'O','O','O','O','O', 'U','U','U','U', 'Y'), $string);
	}

	/**
	 * Turns any given relative path to the absolute version of the path.
	 * @param $relative_path Provide path like 'test/testpath'
	 * @return string
	 */
	public function absolutePath ($relative_path)
	{
		$absolute_path = $this->configuration['absolute_path'] . ltrim($relative_path, '/');
		return str_ireplace('//', '/', $absolute_path);
	}

	/**
	 * Assumes role of loading files.
	 *
	 * @date 20100106 (v1.1) (greg) moved from core to PHPDS_core and added a few checks
	 *
	 * @version 1.1
	 * @author jason
	 *
	 * @param string $file_location
	 * @param boolean Should the file be required or else included.
	 * @param boolean Is this a relative path, if true, it will be converted to absolute path.
	 * @param boolean Should it be called only once?
	 * @return mixed, whatever the file returned when executed or false if it couldn't be found
	 */
	public function loadFile($path, $required = false, $relative = true, $once_only = true)
	{
		if (empty($path)) throw new PHPDS_exception('Trying to load a file with an empty path.');

		$configuration = $this->configuration;
		$db = $this->db;
		$navigation = $this->navigation;
		$security = $this->security;
		$core = $this->core;
		$template = $this->template;
		$lang = $this->lang;
		$ERROR = array();

		// Define.
		$RESULTS = false;
		$alt = false;

		if ($relative) $path = $this->configuration['absolute_path'] . $path;

		$this->log('Loading : ' . $path);

		$debug = $this->debugInstance();
		$debug->domain('user');

		$result = false;

		if (file_exists($path)) {
			if ($required) {
				if (! empty($once_only)) $result = require_once ($path); else $result = require ($path);
			} else {
				if (! empty($once_only)) $result = include_once ($path); else $result = include ($path);
			}
		} else {
			if ($required) throw new PHPDS_exception('Trying to load a non-existant file: "'.$path.'"');
		}
		if (is_string($result) && class_exists($result)) {
			$controller = $this->factory($result);
			$result = $controller->run();
		}

		$this->debugInstance()->domain('core');

		return $result;
	}

	/**
	 * This is a handy little function to strip out a string between two specified pieces of text.
	 * This could be used to parse XML text, bbCode, or any other delimited code/text for that matter.
	 * Can also return all text with replaced string between tags.
	 *
	 * @param string $string
	 * @param string $start
	 * @param string $end
	 * @param string $replace Use %s to be replaced with the string between tags.
	 * @return string
	 */
	public function SearchAndReplaceBetween ($string, $start, $end, $replace = '', $replace_char='%')
	{
		$ini = strpos($string, $start);
		if ($ini === false) return $string;
		$ini += strlen($start);
		$len = strpos($string, $end, $ini) - $ini;
		$string_between = substr($string, $ini, $len);
		if (! empty($replace)) {
			if ($replace_char == '%') {
				$replaced_text = sprintf($replace, $string_between);
				return str_replace($start . $string_between . $end, $replaced_text, $string);
			} else {
				$replaced_text = str_replace($replace_char, $string_between, $replace);
				return str_replace($start . $string_between . $end, $replaced_text, $string);
			}
			return $string;
		} else {
			return $string_between;
		}
	}

	/**
	 * Method is used to wrap the gettext international language conversion tool inside PHPDevShell.
	 * Converts text to use gettext PO system.
	 *
	 * @param string $say_what The string required to output or convert.
	 * @param string $domain Override textdomain that should be looked under for this text string.
	 * @return string Will return converted string or same string if not available.
	 * @author Jason Schoeman
	 */
	public function __ ($say_what, $domain = false)
	{
		return __ ($say_what, $domain);
	}

	/**
	 * Will log current configuration data to firephp.
	 * @return void
	 */
	public function logConfig ()
	{
		$this->_log((array) $this->configuration);
	}
}
