<?php

/**
 * Reads the iana subtag registry as provided by iana and then parses it into arrays.
 *
 * @link http://www.iana.org/assignments/language-subtag-registry
 */
class iana extends PHPDS_dependant
{
	/**
	 * Actual method that reads the iana language registry from the local language folder.
	 * It puts it in an array (language_code, description)
	 *
	 * @return array
	 */
	function readIanaRegistry ($type = 'language')
	{
		// Read the iana file as a string into variable.
		$registry = file_get_contents("plugins/PHPDevShell/includes/iana.$type");
		// Plit blocks of language information up in arrays.
		$registry_items = explode('%%', $registry);
		// Loop blocks of arrays.
		foreach ($registry_items as $item) {
			// Split individual lines inside blocks up in arrays.
			$item_lines = explode("\n", $item);
			// Loop lines.
			foreach ($item_lines as $line) {
				// Check if we met a property + value.
				if (strpos($line, ':') !== false) {
					// Assign array to variables.
					list ($property, $value) = explode(':', $line);
					// If it is a subtag remember value for next loop.
					if ($property == 'Subtag') {
						$subtag = trim($value);
					} // If we have a subtag, write language description.
					else if ($property == 'Description' && ! empty($subtag) && ! empty($value)) {
						$iana_registry[$subtag] = trim($value);
					} // Empty subtag.
					else {
						$subtag = false;
					}
				}
			}
		}
		// Sort and return iana registry array.
		asort($iana_registry);
		return $iana_registry;
	}

	/**
	 * Method generates iana language options.
	 *
	 * @param string $selected_language
	 * @return string
	 */
	public function languageOptions ($selected_language)
	{
		$configuration = $this->configuration;
		$db = $this->db;
		$template = $this->template;
		$core = $this->core;

		// Get required settings.
		$settings = $db->getSettings(array('languages_available'), 'PHPDevShell');
		$languages_available_settings = $settings['languages_available'];
		if (! empty($languages_available_settings)) {
			// Get iana array.
			$iana_array = $this->readIanaRegistry('language');
			// Turn into array.
			$languages_available_array = explode(',', $languages_available_settings);
			// Sort array.
			asort($languages_available_array);
			// System default language string.
			$system_default_language = sprintf(_('Default (%s)'), $iana_array[$configuration['language']]);
			// Default Language.
			$language_option = '<option value="">' . $system_default_language . '</option>';
			// Loop through available languages.
			foreach ($languages_available_array as $lang_code) {
				// Check if any language is selected.
				($lang_code == $selected_language) ? $language_selected = 'selected' : $language_selected = false;
				// Create dropdown.
				$language_option .= '<option value="' . $lang_code . '" ' . $language_selected . '>' . $iana_array[$lang_code] . '</option>';
			}
			// Do we have anything to list?
			if (empty($language_option)) {
				return false;
			} else {
				// Return Options.
				return $language_option;
			}
		}
	}

	/**
	 * Method generates iana region options.
	 *
	 * @param string $selected_region
	 * @return string
	 */
	public function regionOptions ($selected_region)
	{
		$configuration = $this->configuration;
		$db = $this->db;
		$template = $this->template;
		$core = $this->core;
		
		// Get required settings.
		$settings = $db->getSettings(array('regions_available'), 'PHPDevShell');
		$regions_available_settings = $settings['regions_available'];
		if (! empty($regions_available_settings)) {
			// Get iana array.
			$iana_array = $this->readIanaRegistry('region');
			// Turn into array.
			$regions_available_array = explode(',', $regions_available_settings);
			// Sort array.
			asort($regions_available_array);
			// System default region string.
			$system_default_region = sprintf(_('Default (%s)'), $iana_array[$configuration['region']]);
			// Default region.
			$region_option = '<option value="">' . $system_default_region . '</option>';
			// Loop through available regions.
			foreach ($regions_available_array as $region_code) {
				// Check if any region is selected.
				($region_code == $selected_region) ? $region_selected = 'selected' : $region_selected = false;
				// Create dropdown.
				$region_option .= '<option value="' . $region_code . '" ' . $region_selected . '>' . $iana_array[$region_code] . '</option>';
			}

			// Do we have anything to list?
			if (empty($region_option)) {
				return false;
			} else {
				// Return Options.
				return $region_option;
			}
		}
	}
}